@@ -19,7 +19,7 @@ class OrderAdmin(admin.ModelAdmin):
     list_filter = ['status']
 
     search_fields = [
-        'first_name', 'last_name', 'middle_name', 'address', 'mobile', 'email',
+        'first_name', 'last_name', 'middle_name', 'address', 'mobile',
         'comment'
     ]
 
