@@ -17,8 +17,7 @@ def checkout(request):
     if user.is_authenticated:
         initial.update({
             'first_name': user.first_name,
-            'last_name': user.last_name,
-            'email': user.email,
+            'last_name': user.last_name
         })
 
     form = CheckoutForm(
